==> kubernetes-model-apiextensions-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionNamesBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomResourceDefinitionNamesBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesBuilder>{
  public CustomResourceDefinitionNamesBuilder() {
    this(false);
  }
  public CustomResourceDefinitionNamesBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomResourceDefinitionNames(), validationEnabled);
  }
  public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomResourceDefinitionNames(), validationEnabled);
  }
  public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance) {
    this(fluent, instance, false);
  }
  public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCategories(instance.getCategories()); 
    fluent.withKind(instance.getKind()); 
    fluent.withListKind(instance.getListKind()); 
    fluent.withPlural(instance.getPlural()); 
    fluent.withShortNames(instance.getShortNames()); 
    fluent.withSingular(instance.getSingular()); 
    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance) {
    this(instance,false);
  }
  public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCategories(instance.getCategories()); 
    this.withKind(instance.getKind()); 
    this.withListKind(instance.getListKind()); 
    this.withPlural(instance.getPlural()); 
    this.withShortNames(instance.getShortNames()); 
    this.withSingular(instance.getSingular()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames build() {
    CustomResourceDefinitionNames buildable = new CustomResourceDefinitionNames(fluent.getCategories(),fluent.getKind(),fluent.getListKind(),fluent.getPlural(),fluent.getShortNames(),fluent.getSingular());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceDefinitionNamesBuilder that = (CustomResourceDefinitionNamesBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-apiextensions-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionNamesBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomResourceDefinitionNamesBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesBuilder>{
  public CustomResourceDefinitionNamesBuilder() {
    this(false);
  }
  public CustomResourceDefinitionNamesBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomResourceDefinitionNames(), validationEnabled);
  }
  public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomResourceDefinitionNames(), validationEnabled);
  }
  public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance) {
    this(fluent, instance, false);
  }
  public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCategories(instance.getCategories()); 
    fluent.withKind(instance.getKind()); 
    fluent.withListKind(instance.getListKind()); 
    fluent.withPlural(instance.getPlural()); 
    fluent.withShortNames(instance.getShortNames()); 
    fluent.withSingular(instance.getSingular()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance) {
    this(instance,false);
  }
  public CustomResourceDefinitionNamesBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCategories(instance.getCategories()); 
    this.withKind(instance.getKind()); 
    this.withListKind(instance.getListKind()); 
    this.withPlural(instance.getPlural()); 
    this.withShortNames(instance.getShortNames()); 
    this.withSingular(instance.getSingular()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames build() {
    CustomResourceDefinitionNames buildable = new CustomResourceDefinitionNames(fluent.getCategories(),fluent.getKind(),fluent.getListKind(),fluent.getPlural(),fluent.getShortNames(),fluent.getSingular());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceDefinitionNamesBuilder that = (CustomResourceDefinitionNamesBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
